import { minioClient } from '@/app.ts';
import { bucketName } from '@/modules/minio.ts';

type MinioListOpt = {
  prefix: string;
  recursive?: boolean;
};
type MinioFile = {
  name: string;
  size: number;
  lastModified: Date;
  etag: string;
};
type MinioDirectory = {
  prefix: string;
  size: number;
};
type MinioList = (MinioFile | MinioDirectory)[];
export const getMinioList = async (opts: MinioListOpt): Promise<MinioList> => {
  const prefix = opts.prefix;
  const recursive = opts.recursive ?? false;
  return await new Promise((resolve, reject) => {
    let res: any[] = [];
    let hasError = false;
    minioClient
      .listObjectsV2(bucketName, prefix, recursive)
      .on('data', (data) => {
        res.push(data);
      })
      .on('error', (err) => {
        console.error('minio error', opts.prefix, err);
        hasError = true;
      })
      .on('end', () => {
        if (hasError) {
          reject();
          return;
        } else {
          resolve(res);
        }
      });
  });
};
